CursorFormat

Enum CursorFormat 

pub(crate) enum CursorFormat {
    XCursor,
    Scalable,
}
The on-disk format of a cursor within a theme directory.

Variants



XCursor

Legacy raster cursors, stored as a file in cursors/<name>.



Scalable

Scalable SVG cursors, stored as a directory in cursors_scalable/<name>.

Implementations

Source

impl CursorFormat

pub(crate) fn subdir(self) -> &'static str

The theme sub-directory this format lives in.

pub(crate) fn matches(self, path: &Path) -> bool

Whether an entry of this format is a directory (scalable) or a file (xcursor).