pub(crate) enum CursorFormat {
XCursor,
Scalable,
}Expand description
The on-disk format of a cursor within a theme directory.
Variants
XCursor
Legacy raster cursors, stored as a file in cursors/<name>.
Scalable
Scalable SVG cursors, stored as a directory in cursors_scalable/<name>.
Implementations